@@ -21,6 +21,7 @@ class Website:
 
     def __post_init__(self):
         if len(self.last_visited.split('_')) > 1:
+            tracker_log(f'Last Visited Split - {self.last_visited}', 'Website - ')
             self.dimension_key = f'{Type.JSON.value}::{Dimension.WEBSITE.value}:{self.id}::'
             self.dimension_ts_key = f'::{Dimension.WEBSITE.value}:{self.id}:{self.last_visited}:'
             self.metric_pageviews_key = f'{Type.CMS.value}::{Dimension.WEBSITE.value}::{self.last_visited}:{Metric.PAGEVIEWS.value}'
@@ -197,10 +198,10 @@ class Website:
         rounded_record_ts = int(round_time(datetime.fromtimestamp(int(self.last_visited) / 1000) if self.last_visited is not None else None).timestamp() * 1000)
         record_ts = self.last_visited
 
-        rounded_now_dt = datetime.fromtimestamp(rounded_now_ts)
-        now_dt = datetime.fromtimestamp(now_ts)
-        rounded_record_dt = datetime.fromtimestamp(rounded_record_ts)
-        record_dt = datetime.fromtimestamp(int(record_ts))
+        rounded_now_dt = datetime.fromtimestamp(rounded_now_ts / 1000)
+        now_dt = datetime.fromtimestamp(now_ts / 1000)
+        rounded_record_dt = datetime.fromtimestamp(rounded_record_ts / 1000)
+        record_dt = datetime.fromtimestamp(int(record_ts) / 1000)
 
         tracker_log(f'{rounded_now_ts} {now_ts} {rounded_record_ts} {record_ts} - {rounded_now_dt} {now_dt} {rounded_record_dt} {record_dt}', f'Website - ')
 
